<?php
/**
 * Plugin Name: GPT - Custom Cars Post Type
 * Description: Adds a custom post type for 'Cars' with custom meta fields for car specifications and an associated taxonomy for vehicle type. Ensures the use of the classic editor.
 * Author: WPGPTCoder
 * Author URI: https://www.wpappdev.com/product/wp-gpt-coder/
 * Slug: custom-cars-post-type-11854900
 * Version: 1.0
 */

// Register Custom Post Type for Cars
function gpt11854900_register_cars_post_type() {
    $labels = array(
        'name'                  => _x('Cars', 'Post Type General Name', 'text_domain'),
        'singular_name'         => _x('Car', 'Post Type Singular Name', 'text_domain'),
        'menu_name'             => __('Cars', 'text_domain'),
        'name_admin_bar'        => __('Car', 'text_domain'),
        'archives'              => __('Item Archives', 'text_domain'),
        'attributes'            => __('Item Attributes', 'text_domain'),
        'parent_item_colon'     => __('Parent Item:', 'text_domain'),
        'all_items'             => __('All Cars', 'text_domain'),
        'add_new_item'          => __('Add New Car', 'text_domain'),
        'add_new'               => __('Add New', 'text_domain'),
        'new_item'              => __('New Car', 'text_domain'),
        'edit_item'             => __('Edit Car', 'text_domain'),
        'update_item'           => __('Update Car', 'text_domain'),
        'view_item'             => __('View Car', 'text_domain'),
        'view_items'            => __('View Cars', 'text_domain'),
        'search_items'          => __('Search Car', 'text_domain'),
        'not_found'             => __('Not found', 'text_domain'),
        'not_found_in_trash'    => __('Not found in Trash', 'text_domain'),
        'featured_image'        => __('Featured Image', 'text_domain'),
        'set_featured_image'    => __('Set featured image', 'text_domain'),
        'remove_featured_image' => __('Remove featured image', 'text_domain'),
        'use_featured_image'    => __('Use as featured image', 'text_domain'),
        'insert_into_item'      => __('Insert into item', 'text_domain'),
        'uploaded_to_this_item' => __('Uploaded to this item', 'text_domain'),
        'items_list'            => __('Items list', 'text_domain'),
        'items_list_navigation' => __('Items list navigation', 'text_domain'),
        'filter_items_list'     => __('Filter items list', 'text_domain'),
    );
    $args = array(
        'label'                 => __('Car', 'text_domain'),
        'description'           => __('Post Type Description', 'text_domain'),
        'labels'                => $labels,
        'supports'              => array('title', 'editor', 'thumbnail', 'revisions'),
        'hierarchical'          => false,
        'public'                => true,
        'show_ui'               => true,
        'show_in_menu'          => true,
        'menu_position'         => 5,
        'show_in_admin_bar'     => true,
        'show_in_nav_menus'     => true,
        'can_export'            => true,
        'has_archive'           => true,
        'exclude_from_search'   => false,
        'publicly_queryable'    => true,
        'capability_type'       => 'post',
        'show_in_rest'          => false, // Disable Gutenberg editor
    );
    register_post_type('car', $args);
}
add_action('init', 'gpt11854900_register_cars_post_type', 0);

// Register Custom Taxonomy for Vehicle Type
function gpt11854900_register_vehicle_type_taxonomy() {
    $labels = array(
        'name'                       => _x('Vehicle Types', 'Taxonomy General Name', 'text_domain'),
        'singular_name'              => _x('Vehicle Type', 'Taxonomy Singular Name', 'text_domain'),
        'menu_name'                  => __('Vehicle Type', 'text_domain'),
        'all_items'                  => __('All Vehicle Types', 'text_domain'),
        'parent_item'                => __('Parent Vehicle Type', 'text_domain'),
        'parent_item_colon'          => __('Parent Vehicle Type:', 'text_domain'),
        'new_item_name'              => __('New Vehicle Type Name', 'text_domain'),
        'add_new_item'               => __('Add New Vehicle Type', 'text_domain'),
        'edit_item'                  => __('Edit Vehicle Type', 'text_domain'),
        'update_item'                => __('Update Vehicle Type', 'text_domain'),
        'view_item'                  => __('View Vehicle Type', 'text_domain'),
        'separate_items_with_commas' => __('Separate vehicle types with commas', 'text_domain'),
        'add_or_remove_items'        => __('Add or remove vehicle types', 'text_domain'),
        'choose_from_most_used'      => __('Choose from the most used', 'text_domain'),
        'popular_items'              => __('Popular Vehicle Types', 'text_domain'),
        'search_items'               => __('Search Vehicle Types', 'text_domain'),
        'not_found'                  => __('Not Found', 'text_domain'),
        'no_terms'                   => __('No vehicle types', 'text_domain'),
        'items_list'                 => __('Vehicle Types list', 'text_domain'),
        'items_list_navigation'      => __('Vehicle Types list navigation', 'text_domain'),
    );
    $args = array(
        'labels'                     => $labels,
        'hierarchical'               => true,
        'public'                     => true,
        'show_ui'                    => true,
        'show_admin_column'          => true,
        'show_in_nav_menus'          => true,
        'show_tagcloud'              => true,
    );
    register_taxonomy('vehicle_type', array('car'), $args);
}
add_action('init', 'gpt11854900_register_vehicle_type_taxonomy', 0);

// Add custom meta fields for Cars post type
function gpt11854900_add_car_meta_boxes() {
    add_meta_box('car-details', __('Car Details', 'text_domain'), 'gpt11854900_car_details_callback', 'car', 'normal', 'high');
}
add_action('add_meta_boxes', 'gpt11854900_add_car_meta_boxes');

function gpt11854900_car_details_callback($post) {
    wp_nonce_field('gpt11854900_save_car_meta_box_data', 'gpt11854900_car_meta_box_nonce');
    
    $make = get_post_meta($post->ID, 'make', true);
    $model = get_post_meta($post->ID, 'model', true);
    $price = get_post_meta($post->ID, 'price', true);
    $exterior_color = get_post_meta($post->ID, 'exterior_color', true);
    $interior_color = get_post_meta($post->ID, 'interior_color', true);
    $seating_capacity = get_post_meta($post->ID, 'seating_capacity', true);
    $drivetrain = get_post_meta($post->ID, 'drivetrain', true);
    $transmission = get_post_meta($post->ID, 'transmission', true);
    $cylinders = get_post_meta($post->ID, 'cylinders', true);
    $mpg = get_post_meta($post->ID, 'mpg', true);

    // Car details form fields
    echo '<label for="make">' . __('Make', 'text_domain') . '</label>';
    echo '<input type="number" id="make" name="make" value="' . esc_attr($make) . '" size="25" />';

    echo '<label for="model">' . __('Model', 'text_domain') . '</label>';
    echo '<input type="number" id="model" name="model" value="' . esc_attr($model) . '" size="25" />';

    echo '<label for="price">' . __('Price', 'text_domain') . '</label>';
    echo '<input type="number" id="price" name="price" value="' . esc_attr($price) . '" size="25" />';

    echo '<label for="exterior_color">' . __('Exterior Color', 'text_domain') . '</label>';
    echo '<input type="number" id="exterior_color" name="exterior_color" value="' . esc_attr($exterior_color) . '" size="25" />';

    echo '<label for="interior_color">' . __('Interior Color', 'text_domain') . '</label>';
    echo '<input type="number" id="interior_color" name="interior_color" value="' . esc_attr($interior_color) . '" size="25" />';

    echo '<label for="seating_capacity">' . __('Seating Capacity', 'text_domain') . '</label>';
    echo '<input type="number" id="seating_capacity" name="seating_capacity" value="' . esc_attr($seating_capacity) . '" size="25" />';

    echo '<label for="drivetrain">' . __('Drivetrain', 'text_domain') . '</label>';
    echo '<input type="number" id="drivetrain" name="drivetrain" value="' . esc_attr($drivetrain) . '" size="25" />';

    echo '<label for="transmission">' . __('Transmission', 'text_domain') . '</label>';
    echo '<input type="number" id="transmission" name="transmission" value="' . esc_attr($transmission) . '" size="25" />';

    echo '<label for="cylinders">' . __('Cylinders', 'text_domain') . '</label>';
    echo '<input type="number" id="cylinders" name="cylinders" value="' . esc_attr($cylinders) . '" size="25" />';

    echo '<label for="mpg">' . __('MPG', 'text_domain') . '</label>';
    echo '<input type="number" id="mpg" name="mpg" value="' . esc_attr($mpg) . '" size="25" />';
}

// Save custom meta fields data
function gpt11854900_save_car_meta_box_data($post_id) {
    // Check if our nonce is set.
    if (!isset($_POST['gpt11854900_car_meta_box_nonce'])) {
        return;
    }
    // Verify that the nonce is valid.
    if (!wp_verify_nonce($_POST['gpt11854900_car_meta_box_nonce'], 'gpt11854900_save_car_meta_box_data')) {
        return;
    }
    // If this is an autosave, our form has not been submitted, so we don't want to do anything.
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }
    // Check the user's permissions.
    if (isset($_POST['post_type']) && 'car' == $_POST['post_type']) {
        if (!current_user_can('edit_post', $post_id)) {
            return;
        }
    } else {
        if (!current_user_can('edit_page', $post_id)) {
            return;
        }
    }

    // Sanitize and save the data
    $fields = array('make', 'model', 'price', 'exterior_color', 'interior_color', 'seating_capacity', 'drivetrain', 'transmission', 'cylinders', 'mpg');
    foreach ($fields as $field) {
        if (array_key_exists($field, $_POST)) {
            update_post_meta($post_id, $field, sanitize_text_field($_POST[$field]));
        }
    }
}
add_action('save_post', 'gpt11854900_save_car_meta_box_data');